from __future__ import absolute_import, unicode_literals

JOURNAL_CANTDO_LIST = [
    'J Lancet',  # not to be confused with THE Lancet ("Lancet"), this one ended 1965, collection unlikely.
    'Nat Monspel Ser Bot',      # 1972-1973 http://www.unboundmedicine.com/medline/journal/Nat_Monspel_Ser_Bot
    'Nat Prod Lett',        # ended 2002.  http://www.ncbi.nlm.nih.gov/pubmed/?term=%22Nat+Prod+Lett%22[TA]
    'Nat Hist',     # ended 1998.  http://www.ncbi.nlm.nih.gov/pubmed/?term=%22Nat+Hist%22[TA]
    'Nat Mus',      # ended 1980. German.  http://www.ncbi.nlm.nih.gov/pubmed/?term=%22Nat+Mus%22[TA]
    'Nat Syst',     # one article from 1982:  http://www.ncbi.nlm.nih.gov/pubmed/?term=11617791
    'Nat Resour Forum',   # ended 1997. http://www.ncbi.nlm.nih.gov/pubmed/?term=%22Nat+Resour+Forum%22[TA]
    'Nat Law Forum',    # ended 1967. http://www.ncbi.nlm.nih.gov/pubmed/?term=%22Nat+Law+Forum%22[TA]
    'Nat Resour J',     # ended 1982. http://www.ncbi.nlm.nih.gov/pubmed/?term=%22Nat+Resour+J%22[TA]
    'Zhonghua Yi Xue Yi Chuan Xue Za Zhi', # Chinese & DOI won't resolve. (eg. http://dx.doi.org/10.3760/cma.j.issn.1003-9406.2015.05.034)
]

# HELP NEEDED ESPECIALLY WITH CHINESE JOURNALS...!
# http://zhyxycx.periodicals.net.cn/default.html
